@@ -10,7 +10,7 @@
 #' `factor`(default), `interaction` and `ecological`.
 #' @param alpha (optional) Specifies the size of the alpha (confidence level). Default is `0.95`.
 #'
-#' @return A list of tibble with the corresponding result under different detector types.
+#' @return A list.
 #' \describe{
 #' \item{\code{factor}}{the result of spatial rough set-based factor detector}
 #' \item{\code{interaction}}{the result of spatial rough set-based interaction detector}
@@ -45,14 +45,9 @@ srs_geodetector = \(formula, data, wt = NULL, type = "factor", alpha = 0.95){
   }
   data = tibble::as_tibble(data)
 
-  formula = stats::as.formula(formula)
-  formula.vars = all.vars(formula)
-  response = data[, formula.vars[1], drop = TRUE]
-  if (formula.vars[2] == "."){
-    explanatory = data[,-which(colnames(data) == formula.vars[1])]
-  } else {
-    explanatory = subset(data, TRUE, match(formula.vars[-1], colnames(data)))
-  }
+  formulavars = sdsfun::formula_varname(formula, data)
+  response = data[, formulavars[[1]], drop = TRUE]
+  explanatory = data[, formulavars[[2]]]
 
   switch(type,
          "factor" = {
